# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class GetDigitsAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_url': 'str',
        'digit_timeout_ms': 'int',
        'finish_on_key': 'str',
        'flush_buffer': 'bool',
        'initial_timeout_ms': 'str',
        'max_digits': 'int',
        'min_digits': 'int',
        'prompts': 'list[PerclCommand]',
        'privacy_mode': 'bool'
    }

    attribute_map = {
        'action_url': 'actionUrl',
        'digit_timeout_ms': 'digitTimeoutMs',
        'finish_on_key': 'finishOnKey',
        'flush_buffer': 'flushBuffer',
        'initial_timeout_ms': 'initialTimeoutMs',
        'max_digits': 'maxDigits',
        'min_digits': 'minDigits',
        'prompts': 'prompts',
        'privacy_mode': 'privacyMode'
    }

    def __init__(self, action_url=None, digit_timeout_ms=None, finish_on_key=None, flush_buffer=None, initial_timeout_ms=None, max_digits=None, min_digits=None, prompts=None, privacy_mode=None, local_vars_configuration=None):  # noqa: E501
        """GetDigitsAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_url = None
        self._digit_timeout_ms = None
        self._finish_on_key = None
        self._flush_buffer = None
        self._initial_timeout_ms = None
        self._max_digits = None
        self._min_digits = None
        self._prompts = None
        self._privacy_mode = None
        self.discriminator = None

        self.action_url = action_url
        if digit_timeout_ms is not None:
            self.digit_timeout_ms = digit_timeout_ms
        if finish_on_key is not None:
            self.finish_on_key = finish_on_key
        if flush_buffer is not None:
            self.flush_buffer = flush_buffer
        if initial_timeout_ms is not None:
            self.initial_timeout_ms = initial_timeout_ms
        if max_digits is not None:
            self.max_digits = max_digits
        if min_digits is not None:
            self.min_digits = min_digits
        if prompts is not None:
            self.prompts = prompts
        if privacy_mode is not None:
            self.privacy_mode = privacy_mode

    @property
    def action_url(self):
        """Gets the action_url of this GetDigitsAllOf.  # noqa: E501

        When the Caller has finished entering digits, FreeClimb will make an HTTP POST request to this URL. A PerCL response is expected to continue handling the Call. Make sure to keep “http://“ in the URL.  # noqa: E501

        :return: The action_url of this GetDigitsAllOf.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this GetDigitsAllOf.

        When the Caller has finished entering digits, FreeClimb will make an HTTP POST request to this URL. A PerCL response is expected to continue handling the Call. Make sure to keep “http://“ in the URL.  # noqa: E501

        :param action_url: The action_url of this GetDigitsAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action_url is None:  # noqa: E501
            raise ValueError("Invalid value for `action_url`, must not be `None`")  # noqa: E501

        self._action_url = action_url

    @property
    def digit_timeout_ms(self):
        """Gets the digit_timeout_ms of this GetDigitsAllOf.  # noqa: E501

         Maximum time in milliseconds that FreeClimb will wait for the Caller to press any digit after the last digit entered, before making a determination that a `timeout` has occurred and moving on to make the request to the actionUrl to submit the results of the `GetDigits` command. This timeout interval begins and resets after each digit entered.  # noqa: E501

        :return: The digit_timeout_ms of this GetDigitsAllOf.  # noqa: E501
        :rtype: int
        """
        return self._digit_timeout_ms

    @digit_timeout_ms.setter
    def digit_timeout_ms(self, digit_timeout_ms):
        """Sets the digit_timeout_ms of this GetDigitsAllOf.

         Maximum time in milliseconds that FreeClimb will wait for the Caller to press any digit after the last digit entered, before making a determination that a `timeout` has occurred and moving on to make the request to the actionUrl to submit the results of the `GetDigits` command. This timeout interval begins and resets after each digit entered.  # noqa: E501

        :param digit_timeout_ms: The digit_timeout_ms of this GetDigitsAllOf.  # noqa: E501
        :type: int
        """

        self._digit_timeout_ms = digit_timeout_ms

    @property
    def finish_on_key(self):
        """Gets the finish_on_key of this GetDigitsAllOf.  # noqa: E501

        Digit that causes the input sequence to be deemed complete. This attribute defers to the `timeout` attribute – so, if a `timeout` occurs, then the command terminates regardless of the value of `finishOnKey`.  # noqa: E501

        :return: The finish_on_key of this GetDigitsAllOf.  # noqa: E501
        :rtype: str
        """
        return self._finish_on_key

    @finish_on_key.setter
    def finish_on_key(self, finish_on_key):
        """Sets the finish_on_key of this GetDigitsAllOf.

        Digit that causes the input sequence to be deemed complete. This attribute defers to the `timeout` attribute – so, if a `timeout` occurs, then the command terminates regardless of the value of `finishOnKey`.  # noqa: E501

        :param finish_on_key: The finish_on_key of this GetDigitsAllOf.  # noqa: E501
        :type: str
        """

        self._finish_on_key = finish_on_key

    @property
    def flush_buffer(self):
        """Gets the flush_buffer of this GetDigitsAllOf.  # noqa: E501

        If set to true, the FreeClimb platform starts with an empty DTMF buffer to store the digits entered by the caller. If set to false, FreeClimb will append the user inputs to the end of the existing digits buffer and will return digits from the start of the digits buffer.  # noqa: E501

        :return: The flush_buffer of this GetDigitsAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._flush_buffer

    @flush_buffer.setter
    def flush_buffer(self, flush_buffer):
        """Sets the flush_buffer of this GetDigitsAllOf.

        If set to true, the FreeClimb platform starts with an empty DTMF buffer to store the digits entered by the caller. If set to false, FreeClimb will append the user inputs to the end of the existing digits buffer and will return digits from the start of the digits buffer.  # noqa: E501

        :param flush_buffer: The flush_buffer of this GetDigitsAllOf.  # noqa: E501
        :type: bool
        """

        self._flush_buffer = flush_buffer

    @property
    def initial_timeout_ms(self):
        """Gets the initial_timeout_ms of this GetDigitsAllOf.  # noqa: E501

        Maximum time in milliseconds that FreeClimb will wait for the Caller to press the first digit before making a determination that a `timeout` has occurred and moving on to make the request to the `actionUrl` to submit the results of the `GetDigits` command. This timeout interval begins when all nested commands have been fully executed.  # noqa: E501

        :return: The initial_timeout_ms of this GetDigitsAllOf.  # noqa: E501
        :rtype: str
        """
        return self._initial_timeout_ms

    @initial_timeout_ms.setter
    def initial_timeout_ms(self, initial_timeout_ms):
        """Sets the initial_timeout_ms of this GetDigitsAllOf.

        Maximum time in milliseconds that FreeClimb will wait for the Caller to press the first digit before making a determination that a `timeout` has occurred and moving on to make the request to the `actionUrl` to submit the results of the `GetDigits` command. This timeout interval begins when all nested commands have been fully executed.  # noqa: E501

        :param initial_timeout_ms: The initial_timeout_ms of this GetDigitsAllOf.  # noqa: E501
        :type: str
        """

        self._initial_timeout_ms = initial_timeout_ms

    @property
    def max_digits(self):
        """Gets the max_digits of this GetDigitsAllOf.  # noqa: E501

        Maximum number of digits expected in the input. If the terminating digit is not entered and the caller has entered the maximum number of digits allowed, the `GetDigits` command terminates regardless of the value of `finishOnKey`.  # noqa: E501

        :return: The max_digits of this GetDigitsAllOf.  # noqa: E501
        :rtype: int
        """
        return self._max_digits

    @max_digits.setter
    def max_digits(self, max_digits):
        """Sets the max_digits of this GetDigitsAllOf.

        Maximum number of digits expected in the input. If the terminating digit is not entered and the caller has entered the maximum number of digits allowed, the `GetDigits` command terminates regardless of the value of `finishOnKey`.  # noqa: E501

        :param max_digits: The max_digits of this GetDigitsAllOf.  # noqa: E501
        :type: int
        """

        self._max_digits = max_digits

    @property
    def min_digits(self):
        """Gets the min_digits of this GetDigitsAllOf.  # noqa: E501

        Minimum number of digits expected in the input. If specified, FreeClimb will return the collected digits only if the Caller has entered at least that many digits.  # noqa: E501

        :return: The min_digits of this GetDigitsAllOf.  # noqa: E501
        :rtype: int
        """
        return self._min_digits

    @min_digits.setter
    def min_digits(self, min_digits):
        """Sets the min_digits of this GetDigitsAllOf.

        Minimum number of digits expected in the input. If specified, FreeClimb will return the collected digits only if the Caller has entered at least that many digits.  # noqa: E501

        :param min_digits: The min_digits of this GetDigitsAllOf.  # noqa: E501
        :type: int
        """

        self._min_digits = min_digits

    @property
    def prompts(self):
        """Gets the prompts of this GetDigitsAllOf.  # noqa: E501

        JSON array of PerCL commands to nest within the `GetDigits` command. The `Say`, `Play`, and `Pause` commands can be used. The nested actions are executed while FreeClimb is waiting for input from the Caller.  # noqa: E501

        :return: The prompts of this GetDigitsAllOf.  # noqa: E501
        :rtype: list[PerclCommand]
        """
        return self._prompts

    @prompts.setter
    def prompts(self, prompts):
        """Sets the prompts of this GetDigitsAllOf.

        JSON array of PerCL commands to nest within the `GetDigits` command. The `Say`, `Play`, and `Pause` commands can be used. The nested actions are executed while FreeClimb is waiting for input from the Caller.  # noqa: E501

        :param prompts: The prompts of this GetDigitsAllOf.  # noqa: E501
        :type: list[PerclCommand]
        """

        self._prompts = prompts

    @property
    def privacy_mode(self):
        """Gets the privacy_mode of this GetDigitsAllOf.  # noqa: E501

        Parameter `privacyMode` will not log the `text` as required by PCI compliance.  # noqa: E501

        :return: The privacy_mode of this GetDigitsAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._privacy_mode

    @privacy_mode.setter
    def privacy_mode(self, privacy_mode):
        """Sets the privacy_mode of this GetDigitsAllOf.

        Parameter `privacyMode` will not log the `text` as required by PCI compliance.  # noqa: E501

        :param privacy_mode: The privacy_mode of this GetDigitsAllOf.  # noqa: E501
        :type: bool
        """

        self._privacy_mode = privacy_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetDigitsAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetDigitsAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class RecordUtterance(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_url': 'str',
        'silence_timeout_ms': 'int',
        'finish_on_key': 'str',
        'max_length_sec': 'int',
        'play_beep': 'bool',
        'auto_start': 'bool'
    }

    attribute_map = {
        'action_url': 'actionUrl',
        'silence_timeout_ms': 'silenceTimeoutMs',
        'finish_on_key': 'finishOnKey',
        'max_length_sec': 'maxLengthSec',
        'play_beep': 'playBeep',
        'auto_start': 'autoStart'
    }

    def __init__(self, action_url=None, silence_timeout_ms=None, finish_on_key=None, max_length_sec=None, play_beep=None, auto_start=None, local_vars_configuration=None):  # noqa: E501
        """RecordUtterance - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_url = None
        self._silence_timeout_ms = None
        self._finish_on_key = None
        self._max_length_sec = None
        self._play_beep = None
        self._auto_start = None
        self.discriminator = None

        self.action_url = action_url
        if silence_timeout_ms is not None:
            self.silence_timeout_ms = silence_timeout_ms
        if finish_on_key is not None:
            self.finish_on_key = finish_on_key
        if max_length_sec is not None:
            self.max_length_sec = max_length_sec
        if play_beep is not None:
            self.play_beep = play_beep
        if auto_start is not None:
            self.auto_start = auto_start

    @property
    def action_url(self):
        """Gets the action_url of this RecordUtterance.  # noqa: E501

        URL to which information on the completed recording is submitted. The PerCL received in response is then used to continue with Call processing.  # noqa: E501

        :return: The action_url of this RecordUtterance.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this RecordUtterance.

        URL to which information on the completed recording is submitted. The PerCL received in response is then used to continue with Call processing.  # noqa: E501

        :param action_url: The action_url of this RecordUtterance.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action_url is None:  # noqa: E501
            raise ValueError("Invalid value for `action_url`, must not be `None`")  # noqa: E501

        self._action_url = action_url

    @property
    def silence_timeout_ms(self):
        """Gets the silence_timeout_ms of this RecordUtterance.  # noqa: E501

        Interval of silence that should elapse before ending the recording.  # noqa: E501

        :return: The silence_timeout_ms of this RecordUtterance.  # noqa: E501
        :rtype: int
        """
        return self._silence_timeout_ms

    @silence_timeout_ms.setter
    def silence_timeout_ms(self, silence_timeout_ms):
        """Sets the silence_timeout_ms of this RecordUtterance.

        Interval of silence that should elapse before ending the recording.  # noqa: E501

        :param silence_timeout_ms: The silence_timeout_ms of this RecordUtterance.  # noqa: E501
        :type: int
        """

        self._silence_timeout_ms = silence_timeout_ms

    @property
    def finish_on_key(self):
        """Gets the finish_on_key of this RecordUtterance.  # noqa: E501

        Key that triggers the end of the recording. any digit, '#', or '*'  # noqa: E501

        :return: The finish_on_key of this RecordUtterance.  # noqa: E501
        :rtype: str
        """
        return self._finish_on_key

    @finish_on_key.setter
    def finish_on_key(self, finish_on_key):
        """Sets the finish_on_key of this RecordUtterance.

        Key that triggers the end of the recording. any digit, '#', or '*'  # noqa: E501

        :param finish_on_key: The finish_on_key of this RecordUtterance.  # noqa: E501
        :type: str
        """

        self._finish_on_key = finish_on_key

    @property
    def max_length_sec(self):
        """Gets the max_length_sec of this RecordUtterance.  # noqa: E501

        Maximum length for the command execution in seconds.  # noqa: E501

        :return: The max_length_sec of this RecordUtterance.  # noqa: E501
        :rtype: int
        """
        return self._max_length_sec

    @max_length_sec.setter
    def max_length_sec(self, max_length_sec):
        """Sets the max_length_sec of this RecordUtterance.

        Maximum length for the command execution in seconds.  # noqa: E501

        :param max_length_sec: The max_length_sec of this RecordUtterance.  # noqa: E501
        :type: int
        """

        self._max_length_sec = max_length_sec

    @property
    def play_beep(self):
        """Gets the play_beep of this RecordUtterance.  # noqa: E501

        Indicates whether to play a beep sound before the start of the recording. If set to `false`, no beep is played.  # noqa: E501

        :return: The play_beep of this RecordUtterance.  # noqa: E501
        :rtype: bool
        """
        return self._play_beep

    @play_beep.setter
    def play_beep(self, play_beep):
        """Sets the play_beep of this RecordUtterance.

        Indicates whether to play a beep sound before the start of the recording. If set to `false`, no beep is played.  # noqa: E501

        :param play_beep: The play_beep of this RecordUtterance.  # noqa: E501
        :type: bool
        """

        self._play_beep = play_beep

    @property
    def auto_start(self):
        """Gets the auto_start of this RecordUtterance.  # noqa: E501

        If `false`, recording begins immediately after the RecordUtterance command is processed. If `true`, recording begins when audio is present and if audio begins before the `maxLengthSec` timeout. If no audio begins before `maxLengthSec`, no recording is generated.  # noqa: E501

        :return: The auto_start of this RecordUtterance.  # noqa: E501
        :rtype: bool
        """
        return self._auto_start

    @auto_start.setter
    def auto_start(self, auto_start):
        """Sets the auto_start of this RecordUtterance.

        If `false`, recording begins immediately after the RecordUtterance command is processed. If `true`, recording begins when audio is present and if audio begins before the `maxLengthSec` timeout. If no audio begins before `maxLengthSec`, no recording is generated.  # noqa: E501

        :param auto_start: The auto_start of this RecordUtterance.  # noqa: E501
        :type: bool
        """

        self._auto_start = auto_start

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecordUtterance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecordUtterance):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class AddToConferenceAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allow_call_control': 'bool',
        'call_control_sequence': 'str',
        'call_control_url': 'str',
        'conference_id': 'str',
        'call_id': 'bool',
        'leave_conference_url': 'str',
        'listen': 'bool',
        'notification_url': 'str',
        'start_conf_on_enter': 'bool',
        'talk': 'bool'
    }

    attribute_map = {
        'allow_call_control': 'allowCallControl',
        'call_control_sequence': 'callControlSequence',
        'call_control_url': 'callControlUrl',
        'conference_id': 'conferenceId',
        'call_id': 'callId',
        'leave_conference_url': 'leaveConferenceUrl',
        'listen': 'listen',
        'notification_url': 'notificationUrl',
        'start_conf_on_enter': 'startConfOnEnter',
        'talk': 'talk'
    }

    def __init__(self, allow_call_control=None, call_control_sequence=None, call_control_url=None, conference_id=None, call_id=None, leave_conference_url=None, listen=None, notification_url=None, start_conf_on_enter=None, talk=None, local_vars_configuration=None):  # noqa: E501
        """AddToConferenceAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allow_call_control = None
        self._call_control_sequence = None
        self._call_control_url = None
        self._conference_id = None
        self._call_id = None
        self._leave_conference_url = None
        self._listen = None
        self._notification_url = None
        self._start_conf_on_enter = None
        self._talk = None
        self.discriminator = None

        if allow_call_control is not None:
            self.allow_call_control = allow_call_control
        if call_control_sequence is not None:
            self.call_control_sequence = call_control_sequence
        if call_control_url is not None:
            self.call_control_url = call_control_url
        self.conference_id = conference_id
        self.call_id = call_id
        if leave_conference_url is not None:
            self.leave_conference_url = leave_conference_url
        if listen is not None:
            self.listen = listen
        if notification_url is not None:
            self.notification_url = notification_url
        if start_conf_on_enter is not None:
            self.start_conf_on_enter = start_conf_on_enter
        if talk is not None:
            self.talk = talk

    @property
    def allow_call_control(self):
        """Gets the allow_call_control of this AddToConferenceAllOf.  # noqa: E501

        If `true`, Call control will be enabled for this Participant's Call leg.  # noqa: E501

        :return: The allow_call_control of this AddToConferenceAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._allow_call_control

    @allow_call_control.setter
    def allow_call_control(self, allow_call_control):
        """Sets the allow_call_control of this AddToConferenceAllOf.

        If `true`, Call control will be enabled for this Participant's Call leg.  # noqa: E501

        :param allow_call_control: The allow_call_control of this AddToConferenceAllOf.  # noqa: E501
        :type: bool
        """

        self._allow_call_control = allow_call_control

    @property
    def call_control_sequence(self):
        """Gets the call_control_sequence of this AddToConferenceAllOf.  # noqa: E501

        Defines a sequence of digits that, when entered by this caller, invokes the `callControlUrl`. Only digits plus '*', and '#' may be used.  # noqa: E501

        :return: The call_control_sequence of this AddToConferenceAllOf.  # noqa: E501
        :rtype: str
        """
        return self._call_control_sequence

    @call_control_sequence.setter
    def call_control_sequence(self, call_control_sequence):
        """Sets the call_control_sequence of this AddToConferenceAllOf.

        Defines a sequence of digits that, when entered by this caller, invokes the `callControlUrl`. Only digits plus '*', and '#' may be used.  # noqa: E501

        :param call_control_sequence: The call_control_sequence of this AddToConferenceAllOf.  # noqa: E501
        :type: str
        """

        self._call_control_sequence = call_control_sequence

    @property
    def call_control_url(self):
        """Gets the call_control_url of this AddToConferenceAllOf.  # noqa: E501

        URL to be invoked when this Participant enters the digit sequence defined in the `callControlSequence` attribute.  # noqa: E501

        :return: The call_control_url of this AddToConferenceAllOf.  # noqa: E501
        :rtype: str
        """
        return self._call_control_url

    @call_control_url.setter
    def call_control_url(self, call_control_url):
        """Sets the call_control_url of this AddToConferenceAllOf.

        URL to be invoked when this Participant enters the digit sequence defined in the `callControlSequence` attribute.  # noqa: E501

        :param call_control_url: The call_control_url of this AddToConferenceAllOf.  # noqa: E501
        :type: str
        """

        self._call_control_url = call_control_url

    @property
    def conference_id(self):
        """Gets the conference_id of this AddToConferenceAllOf.  # noqa: E501

        ID of the Conference to which to add the Participant (Call leg). Conference must exist or an error will result.  # noqa: E501

        :return: The conference_id of this AddToConferenceAllOf.  # noqa: E501
        :rtype: str
        """
        return self._conference_id

    @conference_id.setter
    def conference_id(self, conference_id):
        """Sets the conference_id of this AddToConferenceAllOf.

        ID of the Conference to which to add the Participant (Call leg). Conference must exist or an error will result.  # noqa: E501

        :param conference_id: The conference_id of this AddToConferenceAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and conference_id is None:  # noqa: E501
            raise ValueError("Invalid value for `conference_id`, must not be `None`")  # noqa: E501

        self._conference_id = conference_id

    @property
    def call_id(self):
        """Gets the call_id of this AddToConferenceAllOf.  # noqa: E501

        ID of the Call that will be added to the specified Conference. The Call must be in progress or an error will result. If the Call is part of an existing Conference, it is first removed from that Conference and is then moved to the new one.  # noqa: E501

        :return: The call_id of this AddToConferenceAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._call_id

    @call_id.setter
    def call_id(self, call_id):
        """Sets the call_id of this AddToConferenceAllOf.

        ID of the Call that will be added to the specified Conference. The Call must be in progress or an error will result. If the Call is part of an existing Conference, it is first removed from that Conference and is then moved to the new one.  # noqa: E501

        :param call_id: The call_id of this AddToConferenceAllOf.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and call_id is None:  # noqa: E501
            raise ValueError("Invalid value for `call_id`, must not be `None`")  # noqa: E501

        self._call_id = call_id

    @property
    def leave_conference_url(self):
        """Gets the leave_conference_url of this AddToConferenceAllOf.  # noqa: E501

        URL to be invoked when the Participant leaves the Conference.   # noqa: E501

        :return: The leave_conference_url of this AddToConferenceAllOf.  # noqa: E501
        :rtype: str
        """
        return self._leave_conference_url

    @leave_conference_url.setter
    def leave_conference_url(self, leave_conference_url):
        """Sets the leave_conference_url of this AddToConferenceAllOf.

        URL to be invoked when the Participant leaves the Conference.   # noqa: E501

        :param leave_conference_url: The leave_conference_url of this AddToConferenceAllOf.  # noqa: E501
        :type: str
        """

        self._leave_conference_url = leave_conference_url

    @property
    def listen(self):
        """Gets the listen of this AddToConferenceAllOf.  # noqa: E501

        If `true`, the Participant joins the Conference with listen privileges. This may be modified later via the REST API or `SetListen` PerCL command.  # noqa: E501

        :return: The listen of this AddToConferenceAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._listen

    @listen.setter
    def listen(self, listen):
        """Sets the listen of this AddToConferenceAllOf.

        If `true`, the Participant joins the Conference with listen privileges. This may be modified later via the REST API or `SetListen` PerCL command.  # noqa: E501

        :param listen: The listen of this AddToConferenceAllOf.  # noqa: E501
        :type: bool
        """

        self._listen = listen

    @property
    def notification_url(self):
        """Gets the notification_url of this AddToConferenceAllOf.  # noqa: E501

        When the Participant enters the Conference, this URL will be invoked using an HTTP POST request with the standard request parameters.  # noqa: E501

        :return: The notification_url of this AddToConferenceAllOf.  # noqa: E501
        :rtype: str
        """
        return self._notification_url

    @notification_url.setter
    def notification_url(self, notification_url):
        """Sets the notification_url of this AddToConferenceAllOf.

        When the Participant enters the Conference, this URL will be invoked using an HTTP POST request with the standard request parameters.  # noqa: E501

        :param notification_url: The notification_url of this AddToConferenceAllOf.  # noqa: E501
        :type: str
        """

        self._notification_url = notification_url

    @property
    def start_conf_on_enter(self):
        """Gets the start_conf_on_enter of this AddToConferenceAllOf.  # noqa: E501

        Flag that indicates whether a Conference starts upon entry of this particular Participant. This is usually set to `true` for moderators and `false` for all other Participants.  # noqa: E501

        :return: The start_conf_on_enter of this AddToConferenceAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._start_conf_on_enter

    @start_conf_on_enter.setter
    def start_conf_on_enter(self, start_conf_on_enter):
        """Sets the start_conf_on_enter of this AddToConferenceAllOf.

        Flag that indicates whether a Conference starts upon entry of this particular Participant. This is usually set to `true` for moderators and `false` for all other Participants.  # noqa: E501

        :param start_conf_on_enter: The start_conf_on_enter of this AddToConferenceAllOf.  # noqa: E501
        :type: bool
        """

        self._start_conf_on_enter = start_conf_on_enter

    @property
    def talk(self):
        """Gets the talk of this AddToConferenceAllOf.  # noqa: E501

        If `true`, the Participant joins the Conference with talk privileges. This may be modified later via the REST API or `SetTalk` PerCL command.   # noqa: E501

        :return: The talk of this AddToConferenceAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._talk

    @talk.setter
    def talk(self, talk):
        """Sets the talk of this AddToConferenceAllOf.

        If `true`, the Participant joins the Conference with talk privileges. This may be modified later via the REST API or `SetTalk` PerCL command.   # noqa: E501

        :param talk: The talk of this AddToConferenceAllOf.  # noqa: E501
        :type: bool
        """

        self._talk = talk

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddToConferenceAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddToConferenceAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class GetSpeech(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_url': 'str',
        'grammar_type': 'int',
        'grammar_file': 'str',
        'grammar_rule': 'bool',
        'play_beep': 'str',
        'prompts': 'list[PerclCommand]',
        'no_input_timeout_ms': 'int',
        'recognition_timeout_ms': 'int',
        'confidence_threshold': 'float',
        'sensitivity_level': 'float',
        'speech_complete_timeout_ms': 'int',
        'speech_incomplete_timeout_ms': 'int',
        'privacy_mode': 'bool'
    }

    attribute_map = {
        'action_url': 'actionUrl',
        'grammar_type': 'grammarType',
        'grammar_file': 'grammarFile',
        'grammar_rule': 'grammarRule',
        'play_beep': 'playBeep',
        'prompts': 'prompts',
        'no_input_timeout_ms': 'noInputTimeoutMs',
        'recognition_timeout_ms': 'recognitionTimeoutMs',
        'confidence_threshold': 'confidenceThreshold',
        'sensitivity_level': 'sensitivityLevel',
        'speech_complete_timeout_ms': 'speechCompleteTimeoutMs',
        'speech_incomplete_timeout_ms': 'speechIncompleteTimeoutMs',
        'privacy_mode': 'privacyMode'
    }

    def __init__(self, action_url=None, grammar_type=None, grammar_file=None, grammar_rule=None, play_beep=None, prompts=None, no_input_timeout_ms=None, recognition_timeout_ms=None, confidence_threshold=None, sensitivity_level=None, speech_complete_timeout_ms=None, speech_incomplete_timeout_ms=None, privacy_mode=None, local_vars_configuration=None):  # noqa: E501
        """GetSpeech - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_url = None
        self._grammar_type = None
        self._grammar_file = None
        self._grammar_rule = None
        self._play_beep = None
        self._prompts = None
        self._no_input_timeout_ms = None
        self._recognition_timeout_ms = None
        self._confidence_threshold = None
        self._sensitivity_level = None
        self._speech_complete_timeout_ms = None
        self._speech_incomplete_timeout_ms = None
        self._privacy_mode = None
        self.discriminator = None

        self.action_url = action_url
        if grammar_type is not None:
            self.grammar_type = grammar_type
        self.grammar_file = grammar_file
        if grammar_rule is not None:
            self.grammar_rule = grammar_rule
        if play_beep is not None:
            self.play_beep = play_beep
        if prompts is not None:
            self.prompts = prompts
        if no_input_timeout_ms is not None:
            self.no_input_timeout_ms = no_input_timeout_ms
        if recognition_timeout_ms is not None:
            self.recognition_timeout_ms = recognition_timeout_ms
        if confidence_threshold is not None:
            self.confidence_threshold = confidence_threshold
        if sensitivity_level is not None:
            self.sensitivity_level = sensitivity_level
        if speech_complete_timeout_ms is not None:
            self.speech_complete_timeout_ms = speech_complete_timeout_ms
        if speech_incomplete_timeout_ms is not None:
            self.speech_incomplete_timeout_ms = speech_incomplete_timeout_ms
        if privacy_mode is not None:
            self.privacy_mode = privacy_mode

    @property
    def action_url(self):
        """Gets the action_url of this GetSpeech.  # noqa: E501

        When the caller has finished speaking or the command has timed out, FreeClimb will make a POST request to this URL. A PerCL response is expected to continue handling the call.  # noqa: E501

        :return: The action_url of this GetSpeech.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this GetSpeech.

        When the caller has finished speaking or the command has timed out, FreeClimb will make a POST request to this URL. A PerCL response is expected to continue handling the call.  # noqa: E501

        :param action_url: The action_url of this GetSpeech.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action_url is None:  # noqa: E501
            raise ValueError("Invalid value for `action_url`, must not be `None`")  # noqa: E501

        self._action_url = action_url

    @property
    def grammar_type(self):
        """Gets the grammar_type of this GetSpeech.  # noqa: E501

        The grammar file type to use for speech recognition. A value of 'URL' indicates the grammarFile attribute specifies a URL that points to the grammar file. A value of `BUILTIN` indicates the grammarFile attribute specifies the name of one of the platform built-in grammar files.  # noqa: E501

        :return: The grammar_type of this GetSpeech.  # noqa: E501
        :rtype: int
        """
        return self._grammar_type

    @grammar_type.setter
    def grammar_type(self, grammar_type):
        """Sets the grammar_type of this GetSpeech.

        The grammar file type to use for speech recognition. A value of 'URL' indicates the grammarFile attribute specifies a URL that points to the grammar file. A value of `BUILTIN` indicates the grammarFile attribute specifies the name of one of the platform built-in grammar files.  # noqa: E501

        :param grammar_type: The grammar_type of this GetSpeech.  # noqa: E501
        :type: int
        """

        self._grammar_type = grammar_type

    @property
    def grammar_file(self):
        """Gets the grammar_file of this GetSpeech.  # noqa: E501

        The grammar file to use for speech recognition. If grammarType is set to URL, this attribute is specified as a download URL.  # noqa: E501

        :return: The grammar_file of this GetSpeech.  # noqa: E501
        :rtype: str
        """
        return self._grammar_file

    @grammar_file.setter
    def grammar_file(self, grammar_file):
        """Sets the grammar_file of this GetSpeech.

        The grammar file to use for speech recognition. If grammarType is set to URL, this attribute is specified as a download URL.  # noqa: E501

        :param grammar_file: The grammar_file of this GetSpeech.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and grammar_file is None:  # noqa: E501
            raise ValueError("Invalid value for `grammar_file`, must not be `None`")  # noqa: E501

        self._grammar_file = grammar_file

    @property
    def grammar_rule(self):
        """Gets the grammar_rule of this GetSpeech.  # noqa: E501

        The grammar rule within the specified grammar file to use for speech recognition. This attribute is optional if `grammarType` is `URL` and ignored if `grammarType` is `BUILTIN`.  # noqa: E501

        :return: The grammar_rule of this GetSpeech.  # noqa: E501
        :rtype: bool
        """
        return self._grammar_rule

    @grammar_rule.setter
    def grammar_rule(self, grammar_rule):
        """Sets the grammar_rule of this GetSpeech.

        The grammar rule within the specified grammar file to use for speech recognition. This attribute is optional if `grammarType` is `URL` and ignored if `grammarType` is `BUILTIN`.  # noqa: E501

        :param grammar_rule: The grammar_rule of this GetSpeech.  # noqa: E501
        :type: bool
        """

        self._grammar_rule = grammar_rule

    @property
    def play_beep(self):
        """Gets the play_beep of this GetSpeech.  # noqa: E501

        Indicates whether a beep should be played just before speech recognition is initiated so that the speaker can start to speak.  # noqa: E501

        :return: The play_beep of this GetSpeech.  # noqa: E501
        :rtype: str
        """
        return self._play_beep

    @play_beep.setter
    def play_beep(self, play_beep):
        """Sets the play_beep of this GetSpeech.

        Indicates whether a beep should be played just before speech recognition is initiated so that the speaker can start to speak.  # noqa: E501

        :param play_beep: The play_beep of this GetSpeech.  # noqa: E501
        :type: str
        """

        self._play_beep = play_beep

    @property
    def prompts(self):
        """Gets the prompts of this GetSpeech.  # noqa: E501

        The JSON array of PerCL commands to nest within the `GetSpeech` command. The `Say`, `Play`, and `Pause` commands can be used. The nested actions are executed while FreeClimb is waiting for input from the caller. This allows for playing menu options to the caller and to prompt for the expected input. These commands stop executing when the caller begins to input speech.  # noqa: E501

        :return: The prompts of this GetSpeech.  # noqa: E501
        :rtype: list[PerclCommand]
        """
        return self._prompts

    @prompts.setter
    def prompts(self, prompts):
        """Sets the prompts of this GetSpeech.

        The JSON array of PerCL commands to nest within the `GetSpeech` command. The `Say`, `Play`, and `Pause` commands can be used. The nested actions are executed while FreeClimb is waiting for input from the caller. This allows for playing menu options to the caller and to prompt for the expected input. These commands stop executing when the caller begins to input speech.  # noqa: E501

        :param prompts: The prompts of this GetSpeech.  # noqa: E501
        :type: list[PerclCommand]
        """

        self._prompts = prompts

    @property
    def no_input_timeout_ms(self):
        """Gets the no_input_timeout_ms of this GetSpeech.  # noqa: E501

        When recognition is started and there is no speech detected for `noInputTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.  # noqa: E501

        :return: The no_input_timeout_ms of this GetSpeech.  # noqa: E501
        :rtype: int
        """
        return self._no_input_timeout_ms

    @no_input_timeout_ms.setter
    def no_input_timeout_ms(self, no_input_timeout_ms):
        """Sets the no_input_timeout_ms of this GetSpeech.

        When recognition is started and there is no speech detected for `noInputTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.  # noqa: E501

        :param no_input_timeout_ms: The no_input_timeout_ms of this GetSpeech.  # noqa: E501
        :type: int
        """

        self._no_input_timeout_ms = no_input_timeout_ms

    @property
    def recognition_timeout_ms(self):
        """Gets the recognition_timeout_ms of this GetSpeech.  # noqa: E501

        When playback of prompts ends and there is no match for `recognitionTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.  # noqa: E501

        :return: The recognition_timeout_ms of this GetSpeech.  # noqa: E501
        :rtype: int
        """
        return self._recognition_timeout_ms

    @recognition_timeout_ms.setter
    def recognition_timeout_ms(self, recognition_timeout_ms):
        """Sets the recognition_timeout_ms of this GetSpeech.

        When playback of prompts ends and there is no match for `recognitionTimeoutMs` milliseconds, the recognizer will terminate the recognition operation.  # noqa: E501

        :param recognition_timeout_ms: The recognition_timeout_ms of this GetSpeech.  # noqa: E501
        :type: int
        """

        self._recognition_timeout_ms = recognition_timeout_ms

    @property
    def confidence_threshold(self):
        """Gets the confidence_threshold of this GetSpeech.  # noqa: E501

        When a recognition resource recognizes a spoken phrase, it associates a confidence level with that match. Parameter `confidenceThreshold` specifies what confidence level is considered a successful match. Values are between 0.0 and 1.0.  # noqa: E501

        :return: The confidence_threshold of this GetSpeech.  # noqa: E501
        :rtype: float
        """
        return self._confidence_threshold

    @confidence_threshold.setter
    def confidence_threshold(self, confidence_threshold):
        """Sets the confidence_threshold of this GetSpeech.

        When a recognition resource recognizes a spoken phrase, it associates a confidence level with that match. Parameter `confidenceThreshold` specifies what confidence level is considered a successful match. Values are between 0.0 and 1.0.  # noqa: E501

        :param confidence_threshold: The confidence_threshold of this GetSpeech.  # noqa: E501
        :type: float
        """

        self._confidence_threshold = confidence_threshold

    @property
    def sensitivity_level(self):
        """Gets the sensitivity_level of this GetSpeech.  # noqa: E501

        The speech recognizer supports a variable level of sound sensitivity. The sensitivityLevel attribute allows for filtering out background noise, so it is not mistaken for speech. Values are between 0.0 and 1.0   # noqa: E501

        :return: The sensitivity_level of this GetSpeech.  # noqa: E501
        :rtype: float
        """
        return self._sensitivity_level

    @sensitivity_level.setter
    def sensitivity_level(self, sensitivity_level):
        """Sets the sensitivity_level of this GetSpeech.

        The speech recognizer supports a variable level of sound sensitivity. The sensitivityLevel attribute allows for filtering out background noise, so it is not mistaken for speech. Values are between 0.0 and 1.0   # noqa: E501

        :param sensitivity_level: The sensitivity_level of this GetSpeech.  # noqa: E501
        :type: float
        """

        self._sensitivity_level = sensitivity_level

    @property
    def speech_complete_timeout_ms(self):
        """Gets the speech_complete_timeout_ms of this GetSpeech.  # noqa: E501

        Parameter `speechCompleteTimeoutMs` specifies the length of silence required following user speech before the speech recognizer finalizes a result. This timeout applies when the recognizer currently has a complete match against an active grammar. Reasonable speech complete timeout values are typically in the range of 0.3 seconds to 1.0 seconds.  # noqa: E501

        :return: The speech_complete_timeout_ms of this GetSpeech.  # noqa: E501
        :rtype: int
        """
        return self._speech_complete_timeout_ms

    @speech_complete_timeout_ms.setter
    def speech_complete_timeout_ms(self, speech_complete_timeout_ms):
        """Sets the speech_complete_timeout_ms of this GetSpeech.

        Parameter `speechCompleteTimeoutMs` specifies the length of silence required following user speech before the speech recognizer finalizes a result. This timeout applies when the recognizer currently has a complete match against an active grammar. Reasonable speech complete timeout values are typically in the range of 0.3 seconds to 1.0 seconds.  # noqa: E501

        :param speech_complete_timeout_ms: The speech_complete_timeout_ms of this GetSpeech.  # noqa: E501
        :type: int
        """

        self._speech_complete_timeout_ms = speech_complete_timeout_ms

    @property
    def speech_incomplete_timeout_ms(self):
        """Gets the speech_incomplete_timeout_ms of this GetSpeech.  # noqa: E501

        Parameter `speechIncompleteTimeoutMs` specifies the length of silence following user speech after which a recognizer finalizes a result. This timeout applies when the speech prior to the silence is an incomplete match of all active grammars. Timeout `speechIncompleteTimeoutMs` is usually longer than `speechCompleteTimeoutMs` to allow users to pause mid-utterance.  # noqa: E501

        :return: The speech_incomplete_timeout_ms of this GetSpeech.  # noqa: E501
        :rtype: int
        """
        return self._speech_incomplete_timeout_ms

    @speech_incomplete_timeout_ms.setter
    def speech_incomplete_timeout_ms(self, speech_incomplete_timeout_ms):
        """Sets the speech_incomplete_timeout_ms of this GetSpeech.

        Parameter `speechIncompleteTimeoutMs` specifies the length of silence following user speech after which a recognizer finalizes a result. This timeout applies when the speech prior to the silence is an incomplete match of all active grammars. Timeout `speechIncompleteTimeoutMs` is usually longer than `speechCompleteTimeoutMs` to allow users to pause mid-utterance.  # noqa: E501

        :param speech_incomplete_timeout_ms: The speech_incomplete_timeout_ms of this GetSpeech.  # noqa: E501
        :type: int
        """

        self._speech_incomplete_timeout_ms = speech_incomplete_timeout_ms

    @property
    def privacy_mode(self):
        """Gets the privacy_mode of this GetSpeech.  # noqa: E501

        Parameter privacyMode will not log the `text` as required by PCI compliance.  # noqa: E501

        :return: The privacy_mode of this GetSpeech.  # noqa: E501
        :rtype: bool
        """
        return self._privacy_mode

    @privacy_mode.setter
    def privacy_mode(self, privacy_mode):
        """Sets the privacy_mode of this GetSpeech.

        Parameter privacyMode will not log the `text` as required by PCI compliance.  # noqa: E501

        :param privacy_mode: The privacy_mode of this GetSpeech.  # noqa: E501
        :type: bool
        """

        self._privacy_mode = privacy_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetSpeech):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetSpeech):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])
